"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const logger_1 = require("../logger");
const utils_1 = require("./utils");
// tslint:disable:jsdoc-format
/**
 * Parse a dynamodb segement. DynamoDB segment will look like this:
 *
 * {
                        "id": "491547679650c254",
                        "name": "DynamoDB",
                        "start_time": 1515258497.911,
                        "end_time": 1515258501.692,
                        "http": {
                            "response": {
                                "status": 200
                            }
                        },
                        "aws": {
                            "operation": "PutItem",
                            "region": "us-east-1",
                            "request_id": "E6QO2IJHL85I63K7N7KIQPP1UFVV4KQNSO5AEMVJF66Q9ASUAAJG",
                            "retries": 0,
                            "table_name": "gen-docs",
                            "consumed_capacity": {
                                "TableName": "gen-docs",
                                "CapacityUnits": 1
                            },
                            "resource_names": [
                                "gen-docs"
                            ]
                        },
                        "namespace": "aws"
          }
 * @param segmentDoc
 * @param actionsMap
 */
const parseSegment = function (segmentDoc, actionsMap, functionArn) {
    const aws = segmentDoc.aws;
    if (lodash_1.isEmpty(aws) || !aws.table_name) {
        logger_1.logger.warn("Couldn't extract DynamoDB info for segment document: ", segmentDoc);
        return;
    }
    const region = aws.region || utils_1.extractRegion(functionArn);
    //construct the arn		
    const arn = `arn:aws:dynamodb:${region}:*:table/${aws.table_name}`;
    let actions = actionsMap.get(arn);
    if (!actions) {
        actions = new Set();
        actionsMap.set(arn, actions);
    }
    actions.add(aws.operation);
};
// tslint:enable:jsdoc-format
exports.default = parseSegment;
//# sourceMappingURL=dynamo.js.map