"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const URL = __importStar(require("url"));
function extractRegion(functionArn) {
    const prefix = "arn:aws:lambda:";
    if (functionArn.startsWith(prefix)) {
        return functionArn.slice(prefix.length, functionArn.indexOf(':', prefix.length));
    }
    else {
        logger_1.logger.warn("Arn: [%s] doesn't start with prefix: %s. Can't extract region will use env.AWS_REGION.", functionArn, prefix);
        return process.env.AWS_REGION;
    }
}
exports.extractRegion = extractRegion;
/**
 * Extract region info assuming it appears in the host part after the amazonaws.com part.
 * For example: https://sqs.us-east-1.amazonaws.com/1111111111/test-msg-queue
 * @param urlSrt
 */
function extractRegionFromUrl(urlSrt) {
    const urlObj = URL.parse(urlSrt);
    const host = urlObj.hostname;
    if (!host) {
        return undefined;
    }
    const regexMatch = host.match(/.*\.(.+)\.amazonaws.com$/);
    if (!regexMatch || regexMatch.length < 2) {
        return undefined;
    }
    return regexMatch[1];
}
exports.extractRegionFromUrl = extractRegionFromUrl;
/**
 * Check if a string starts with any of the passed strings. Returned the prefix string of undefined.
 */
function startsWithAny(s, toCheck) {
    return toCheck.find((v) => {
        return s.startsWith(v);
    });
}
exports.startsWithAny = startsWithAny;
/**
 * remove the account id (if exists) and replace with star (*)
 */
function removeAccountIdFromArn(arn) {
    const match = arn.match(/arn:aws:.+?:.*?:(.+?):/);
    if (!match || match.length < 2) {
        return arn;
    }
    return arn.replace(`:${match[1]}:`, ':*:');
}
exports.removeAccountIdFromArn = removeAccountIdFromArn;
//# sourceMappingURL=utils.js.map