import { IamStatement } from "./aws-segments/iam-policy";
import * as AWS from 'aws-sdk';
export declare type PolicyActionMap = Map<string, Set<string>>;
export declare class IamPolicyUtils {
    iam: AWS.IAM;
    constructor();
    createPolicyActionMap(policy: IamStatement[]): PolicyActionMap;
    /**
     * Try to unite statements according to resource for the ones where an action has a single resource.
     * So a resource will appear only once with all relevant statements.
     * @param statements iam statements
     */
    uniteStatments(statements: IamStatement[]): IamStatement[];
    /**
     * Check if effective policy has more permissions than the desired policy (runtime). Will only check for supported services.
     * Only compares allow statements.
     */
    checkExcessPolicyPermissions(effectiveStatements: IamStatement[], desiredStatements: IamStatement[]): IamStatement[] | undefined;
    /**
     * Parse the doc and add statements to the passed array
     * @param doc
     * @param statemetnts
     */
    parsePolicyDoc(doc: string | undefined, statements: IamStatement[]): void;
    /**
     * Get a single statements array which combines the various policies attached to a role
     * @param roleName - arn of the desired role
     */
    getCombinedStatementsForRole(roleName: string): Promise<IamStatement[]>;
}
