import AWS from 'aws-sdk';
import { IamPolicyDocument, IamStatement } from './aws-segments/iam-policy';
export declare const EXCESSIVE_PERMISSION_FILE = "excessive_permissions.json";
export interface ScanXrayTracesConf {
    /**
     * start time to search for. If not specified will do a "last x min search"
     */
    startTime?: Date;
    /**
     * Time in minutes range to search. If startTime is not specified this will be used as a last X min search.
     * Defaults to: 60
     */
    timeRangeMinutes?: number;
    /**
     * Filter expression as documented at: https://docs.aws.amazon.com/xray/latest/devguide/xray-console-filters.html#console-filters-syntax
     */
    filterExpression?: string;
    /**
     * Perform comparison against the application role and generate an excess permissions report
     */
    compareExistingRole?: boolean;
}
/**
 * Fetch xray traces. Combines the two functions of getTraceSummaries and batchGetTraces including support for pagination.
 */
export declare function getXrayTraces(conf?: ScanXrayTracesConf): Promise<AWS.XRay.Trace[]>;
/**
 * Maps that maps a resource to set of actions
 */
export declare type ResourceActionMap = Map<string, Set<string>>;
/**
 * Map which maps a function to the set of ResourceActionMap
 */
export declare type FunctionToActionsMap = Map<string, ResourceActionMap>;
/**
 * Parse an xray trace return the passed in functionMap
 * @param trace
 * @param functionMap will populate with the found results
 */
export declare function parseXrayTrace(trace: AWS.XRay.Trace, functionMap: FunctionToActionsMap): FunctionToActionsMap;
export declare function parseXrayTraces(traces: AWS.XRay.Trace[], functionMap: FunctionToActionsMap): FunctionToActionsMap;
export declare function getFunctionActionMapFromXray(conf?: ScanXrayTracesConf): Promise<Map<string, Map<string, Set<string>>>>;
export declare function createIAMPolicyDoc(map: ResourceActionMap, functionArn: string): IamPolicyDocument;
export interface AppExcessPermissions {
    arn: string;
    role: string;
    excessPermissions: IamStatement[];
}
export declare function compareLambdaRoleToPolicy(lambdaArn: string, policy: IamPolicyDocument): Promise<AppExcessPermissions | undefined>;
export interface GeneratedPolicy {
    Arn: string;
    FileName?: string;
    Policy: IamPolicyDocument;
}
export interface ScanResult {
    GeneratedPolicies: GeneratedPolicy[];
    ExcessPermissions: AppExcessPermissions[];
}
/**
 * Will scan xray and return a ScanResult
 * @param conf
 */
export declare function scanXray(conf: ScanXrayTracesConf): Promise<ScanResult>;
/**
 *
 * @param conf
 * @return object mapping function arn to file name
 */
export declare function scanXrayAndSaveFiles(conf: ScanXrayTracesConf): Promise<ScanResult>;
